"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.CapabilityService = void 0;
var reflection_service_1 = require("./reflection.service");
var CapabilityService = /** @class */ (function () {
    function CapabilityService(project) {
        this.project = project;
        this.reflectionService = new reflection_service_1.ReflectionService();
    }
    CapabilityService.prototype.scan = function (configurationResource) {
        var capabilities = [];
        capabilities.push.apply(capabilities, this.scanCapabilitiesBasedOnDecorators());
        capabilities.push.apply(capabilities, this.scanCapabilitiesBasedOnPackageJson(configurationResource));
        return capabilities;
    };
    CapabilityService.prototype.scanCapabilitiesBasedOnPackageJson = function (configurationResource) {
        if (configurationResource == null) {
            return [];
        }
        return configurationResource.getCapabilities();
    };
    CapabilityService.prototype.scanCapabilitiesBasedOnDecorators = function () {
        var _this = this;
        var capabilities = [];
        this.reflectionService.visitClassDecorators(this.project, function (d) {
            var capability = _this.getCapabilityFromDecorator(d);
            if (capability != null) {
                capabilities.push(capability);
            }
            var groupedCapabilities = _this.getCapabilitiesFromDecorator(d);
            groupedCapabilities.forEach(function (c) { return capabilities.push(c); });
        });
        return capabilities;
    };
    CapabilityService.prototype.getCapabilityFromDecorator = function (d) {
        var name = this.reflectionService.getValueFromDecorator(d, "ContextCapability");
        if (name != null) {
            return { name: name };
        }
        return null;
    };
    CapabilityService.prototype.getCapabilitiesFromDecorator = function (d) {
        var names = this.reflectionService.getArrayValueFromDecorator(d, "ContextCapabilities");
        var capabilities = names.map(function (name) {
            return { name: name };
        });
        return capabilities;
    };
    return CapabilityService;
}());
exports.CapabilityService = CapabilityService;
