"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.ExemplarService = void 0;
var reflection_service_1 = require("./reflection.service");
var version_control_service_1 = require("./version-control.service");
var ExemplarService = /** @class */ (function () {
    function ExemplarService(project) {
        this.project = project;
        this.reflectionService = new reflection_service_1.ReflectionService();
        this.versionControlService = new version_control_service_1.VersionControlService();
    }
    ExemplarService.prototype.scan = function () {
        var _this = this;
        try {
            var exemplars_1 = [];
            this.reflectionService.visitClassDecorators(this.project, function (d, classDeclaration) {
                var exemplar = _this.getExemplarFromDecorator(d, classDeclaration);
                if (exemplar != null) {
                    exemplars_1.push(exemplar);
                }
            });
            return exemplars_1;
        }
        catch (err) {
            console.error("Error while scanning exemplars: " + err);
            return [];
        }
    };
    ExemplarService.prototype.getExemplarFromDecorator = function (d, classDeclaration) {
        if (d.getFullName() !== 'ContextExemplar') {
            return null;
        }
        var origin = this.versionControlService.getRemoteOriginUrl();
        if (origin == null || origin.length === 0) {
            return null;
        }
        var exemplarFileName = classDeclaration.getSourceFile().getBaseName();
        var exemplarFolder = classDeclaration.getSourceFile().getDirectoryPath();
        /*
        * Instead of creating path from git-root to project folder, and a path from project folder to the file.
        * We will directly create a path from the git-root to the file, and mark the other path as empty.
        * The end result is the same, and this requires us to only do a single relative path calculation.
        */
        var pathFromRootToFile = this.versionControlService.getRelativePathToVersionRoot(exemplarFolder);
        if (pathFromRootToFile != null && pathFromRootToFile.length > 0) {
            if (!pathFromRootToFile.endsWith('/')) {
                pathFromRootToFile = pathFromRootToFile + '/';
            }
            pathFromRootToFile = pathFromRootToFile + exemplarFileName;
        }
        var remoteLocation = {
            branch: this.versionControlService.getBranch(),
            relativePathToFile: pathFromRootToFile,
            remoteOriginUrl: origin,
            relativePathToVersionRoot: ''
        };
        var title = this.reflectionService.getValueFromDecorator(d, 'ContextExemplar', 'title');
        if (title == null || title.length === 0) {
            return null;
        }
        var description = this.reflectionService.getValueFromDecorator(d, 'ContextExemplar', 'description');
        var tags = this.reflectionService.getValueFromDecorator(d, 'ContextExemplar', 'tags');
        var exemplar = {
            title: title,
            description: description,
            tags: tags,
            remoteLocation: remoteLocation
        };
        return exemplar;
    };
    return ExemplarService;
}());
exports.ExemplarService = ExemplarService;
